# PrYmes

![PyPI - Version](https://img.shields.io/pypi/v/prymes)
![PyPI - License](https://img.shields.io/pypi/l/prymes)

Python package for prime-related things.

## Install

### (Recommended) pip

To install PrYmes using pip, run the following command:
```
pip install prymes
```

### Source

To install PrYmes from source, clone PrYmes' Github repository using `git`:
```
git clone https://github.com/cyan-ice/prymes.git
```
Then, in the `prymes` repository you just cloned, execute the following command:
```
pip install dist/ap_int-*-py3-none-any.whl
```
Where `*` is the latest version of PrYmes.

## Testing

To execute all tests, run
```
python tests/test.py
```
In the current directory.

You should see something like this:
```
Test #1: primality_test_fixed... Passed
Passed 1/1
```

## Documentation

The documentation is at https://prymes-docs.readthedocs.io/en/latest/.